@@ -1,3 +1,3 @@
 from .si import Server
 from .parser import Parser
-import .formatting as format_codes
\ No newline at end of file
+from . import formatting as format_codes
\ No newline at end of file
